@@ -8,12 +8,29 @@ module Fiddle
   class TestHandle < TestCase
     include Fiddle
 
+    def test_library_unavailable
+      assert_raise(DLError) do
+        Fiddle::Handle.new("does-not-exist-library")
+      end
+      assert_raise(DLError) do
+        Fiddle::Handle.new("/does/not/exist/library.#{RbConfig::CONFIG['SOEXT']}")
+      end
+    end
+
     def test_to_i
+      if ffi_backend?
+        omit("Fiddle::Handle#to_i is unavailable with FFI backend")
+      end
+
       handle = Fiddle::Handle.new(LIBC_SO)
       assert_kind_of Integer, handle.to_i
     end
 
     def test_to_ptr
+      if ffi_backend?
+        omit("Fiddle::Handle#to_i is unavailable with FFI backend")
+      end
+
       handle = Fiddle::Handle.new(LIBC_SO)
       ptr = handle.to_ptr
       assert_equal ptr.to_i, handle.to_i
@@ -26,6 +43,10 @@ module Fiddle
     end
 
     def test_static_sym
+      if ffi_backend?
+        omit("We can't assume static symbols with FFI backend")
+      end
+
       begin
         # Linux / Darwin / FreeBSD
         refute_nil Fiddle::Handle.sym('dlopen')
@@ -90,6 +111,10 @@ module Fiddle
     end
 
     def test_initialize_noargs
+      if RUBY_ENGINE == "jruby"
+        omit("rb_str_new() doesn't exist in JRuby")
+      end
+
       handle = Handle.new
       refute_nil handle['rb_str_new']
     end
@@ -117,6 +142,10 @@ module Fiddle
     end
 
     def test_file_name
+      if ffi_backend?
+        omit("Fiddle::Handle#file_name doesn't exist in FFI backend")
+      end
+
       file_name = Handle.new(LIBC_SO).file_name
       if file_name
         assert_kind_of String, file_name
@@ -135,6 +164,10 @@ module Fiddle
     end
 
     def test_NEXT
+      if ffi_backend?
+        omit("Fiddle::Handle::NEXT doesn't exist in FFI backend")
+      end
+
       begin
         # Linux / Darwin
         #
@@ -173,9 +206,13 @@ module Fiddle
     end unless /mswin|mingw/ =~ RUBY_PLATFORM
 
     def test_DEFAULT
+      if Fiddle::WINDOWS
+        omit("Fiddle::Handle::DEFAULT doesn't have malloc() on Windows")
+      end
+
       handle = Handle::DEFAULT
       refute_nil handle['malloc']
-    end unless /mswin|mingw/ =~ RUBY_PLATFORM
+    end
 
     def test_dlerror
       # FreeBSD (at least 7.2 to 7.2) calls nsdispatch(3) when it calls
@@ -183,27 +220,14 @@ module Fiddle
       # it calls _nss_cache_cycle_prevention_function with dlsym(3).
       # So our Fiddle::Handle#sym must call dlerror(3) before call dlsym.
       # In general uses of dlerror(3) should call it before use it.
+      verbose, $VERBOSE = $VERBOSE, nil
       require 'socket'
       Socket.gethostbyname("localhost")
       Fiddle.dlopen("/lib/libc.so.7").sym('strcpy')
+    ensure
+      $VERBOSE = verbose
     end if /freebsd/=~ RUBY_PLATFORM
 
-    def test_no_memory_leak
-      # https://github.com/ruby/fiddle/actions/runs/3202406059/jobs/5231356410
-      omit if RUBY_VERSION >= '3.2'
-
-      if respond_to?(:assert_nothing_leaked_memory)
-        n_tries = 100_000
-        assert_nothing_leaked_memory(SIZEOF_VOIDP * (n_tries / 100)) do
-          n_tries.times do
-            Fiddle::Handle.allocate
-          end
-        end
-      else
-        assert_no_memory_leak(%w[-W0 -rfiddle.so], '', '100_000.times {Fiddle::Handle.allocate}; GC.start', rss: true)
-      end
-    end
-
     if /cygwin|mingw|mswin/ =~ RUBY_PLATFORM
       def test_fallback_to_ansi
         k = Fiddle::Handle.new("kernel32.dll")
@@ -211,5 +235,10 @@ module Fiddle
         assert_equal(ansi, k["GetFileAttributes"], "should fallback to ANSI version")
       end
     end
+
+    def test_ractor_shareable
+      omit("Need Ractor") unless defined?(Ractor)
+      assert_ractor_shareable(Fiddle::Handle.new(LIBC_SO))
+    end
   end
 end if defined?(Fiddle)
